@@ -1407,7 +1407,7 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
 		inpTracePtr = &chanbuf[k].buf[0];        
 	
 		/* Move the trace */
-		memcpy( (void*)myTracePtr, (void*)inpTracePtr, trace2_hdr->nsamp*sizeof(long) ); 
+		memcpy( (void*)myTracePtr, (void*)inpTracePtr, trace2_hdr->nsamp*sizeof(int32_t) );
     	
 		out_message_size = sizeof(TRACE2_HEADER)+sizeof(int)*trace2_hdr->nsamp;
 		
