@@ -22,8 +22,10 @@
 /* VERSION number introduced by Paul F EW 7.7 Sept 4, 2013 */
 
 /* 0.0.10 2014.02.26 - put in a LOCALMAG amplitude multiplier as a #define in nordic.c for amps from localmag */
+/* 0.0.11 2015.06.13 - more logging for debugging purposes */
+/* 0.0.12 2016.05.31 - Added cast to 'sprintf' param (for 64 bit); minor mods to squelch warnings. */
 
-#define VERSION "0.0.11 2015.06.13"
+#define VERSION "0.0.12 2016.05.31"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -241,7 +243,7 @@ int main( int argc, char **argv )
 				else if( res == GET_TOOBIG )
 				{
 					sprintf( Text, "Retrieved msg[%ld] (i%u m%u t%u) too big for eqmsg[%ld]",
-							recsize, reclogo.instid, reclogo.mod, reclogo.type, sizeof (eqmsg ) - 1 );
+							recsize, reclogo.instid, reclogo.mod, reclogo.type, (long)(sizeof (eqmsg ) - 1) );
 					seisan_report_status( TypeError, ERR_TOOBIG, Text );
 					continue;
 				}
@@ -421,7 +423,7 @@ void seisan_report_sfile( struct event_details* ep )
 
 	int i;//, j;
 	
-	Nordic *event;
+	Nordic *ptrevt;
 
 
 	if( Debug )
@@ -432,7 +434,7 @@ void seisan_report_sfile( struct event_details* ep )
 	{
 		if( Debug )
 			logit( "o", "seisan_report: Converting hypocenter and local magnitude to seisan\n" );
-		if( arc2nor( &event, &( ep->arc ), &( ep->mag ), Agency ) < 0 )
+		if( arc2nor( &ptrevt, &( ep->arc ), &( ep->mag ), Agency ) < 0 )
 		{
 			logit( "e", "seisan_report: Error converting event %s to nordic event\n", ep->qid );
 			return;
@@ -442,7 +444,7 @@ void seisan_report_sfile( struct event_details* ep )
 	{
 		if( Debug )
 			logit( "o", "seisan_report: Converting hypocenter only to seisan\n" );
-		if( arc2nor( &event, &( ep->arc ), NULL, Agency ) < 0 )
+		if( arc2nor( &ptrevt, &( ep->arc ), NULL, Agency ) < 0 )
 		{
 			logit( "e", "seisan_report: Error converting event %s to nordic event\n", ep->qid );
 			return;
@@ -455,7 +457,7 @@ void seisan_report_sfile( struct event_details* ep )
 	/* Add waveform references to seisan event */
 	for( i = 0; i < nwfiles; i++ )
 	{
-		NorAddWaveRef( event, wfiles[i] );
+		NorAddWaveRef( ptrevt, wfiles[i] );
 		
 		/* Memory of this waveform refernce */
 		free( wfiles[i] );
@@ -470,15 +472,15 @@ void seisan_report_sfile( struct event_details* ep )
 	if( ( fp_s = fopen( sfile_name, "w" ) ) == ( FILE * ) NULL )
 	{
 		logit( "et", "seisan_report: error opening file <%s>\n", sfile_name );
-		freeNordic( event );
+		freeNordic( ptrevt );
 		return;
 	}
 	
 	/* Write seisan file */
-	fwriteNor( fp_s, event );
+	fwriteNor( fp_s, ptrevt );
 	
 	/* Release nordic event */
-	freeNordic( event );
+	freeNordic( ptrevt );
 
 	fclose( fp_s );
 	if( Debug )
@@ -818,7 +820,7 @@ void seisan_report_config( char *configfile )
 					logit( "e", "; max=%d; exiting!\n", ( int ) MAXLOGO / 2 );
 					exit( -1 );
 				}
-				if( ( str = k_str( ) ) )
+				if( ( str = k_str( ) ) != NULL )
 				{
 					if( GetInst( str, &GetLogo[nLogo].instid ) != 0 )
 					{
@@ -829,7 +831,7 @@ void seisan_report_config( char *configfile )
 					}
 					GetLogo[nLogo + 1].instid = GetLogo[nLogo].instid;
 				}
-				if( ( str = k_str( ) ) )
+				if( ( str = k_str( ) ) != NULL )
 				{
 					if( GetModId( str, &GetLogo[nLogo].mod ) != 0 )
 					{
@@ -1055,19 +1057,19 @@ void seisan_report_status( unsigned char type, short ierr, char *note )
 
 	if( type == TypeHeartBeat )
 	{
-		sprintf( msg, "%ld %d\n", t, MyPid );
+		sprintf( msg, "%ld %d\n", (long)t, MyPid );
 	}
 	else if( type == TypeError )
 	{
-		sprintf( msg, "%ld %hd %s\n", t, ierr, note );
+		sprintf( msg, "%ld %hd %s\n", (long)t, ierr, note );
 		logit( "et", "seisan_report: %s\n", note );
 	}
 	else if( type == TypeAlarm )
 	{
-		sprintf( msg, "%ld %s\n", t, note );
+		sprintf( msg, "%ld %s\n", (long)t, note );
 	}
 
-	size = strlen( msg ); /* don't include the null byte in the message */
+	size = (long)strlen( msg ); /* don't include the null byte in the message */
 
 	/* Write the message to shared memory
 	 ************************************/
